@@ -3,22 +3,19 @@
  *
  * @APPLE_LICENSE_HEADER_START@
  * 
- * Copyright (c) 1999-2003 Apple Computer, Inc.  All Rights Reserved.
+ * The contents of this file constitute Original Code as defined in and
+ * are subject to the Apple Public Source License Version 1.1 (the
+ * "License").  You may not use this file except in compliance with the
+ * License.  Please obtain a copy of the License at
+ * http://www.apple.com/publicsource and read it before using this file.
  * 
- * This file contains Original Code and/or Modifications of Original Code
- * as defined in and that are subject to the Apple Public Source License
- * Version 2.0 (the 'License'). You may not use this file except in
- * compliance with the License. Please obtain a copy of the License at
- * http://www.opensource.apple.com/apsl/ and read it before using this
- * file.
- * 
- * The Original Code and all software distributed under the License are
- * distributed on an 'AS IS' basis, WITHOUT WARRANTY OF ANY KIND, EITHER
+ * This Original Code and all software distributed under the License are
+ * distributed on an "AS IS" basis, WITHOUT WARRANTY OF ANY KIND, EITHER
  * EXPRESS OR IMPLIED, AND APPLE HEREBY DISCLAIMS ALL SUCH WARRANTIES,
  * INCLUDING WITHOUT LIMITATION, ANY WARRANTIES OF MERCHANTABILITY,
- * FITNESS FOR A PARTICULAR PURPOSE, QUIET ENJOYMENT OR NON-INFRINGEMENT.
- * Please see the License for the specific language governing rights and
- * limitations under the License.
+ * FITNESS FOR A PARTICULAR PURPOSE OR NON-INFRINGEMENT.  Please see the
+ * License for the specific language governing rights and limitations
+ * under the License.
  * 
  * @APPLE_LICENSE_HEADER_END@
  */
@@ -281,7 +278,6 @@ bool BMacEnet::start(IOService * provider)
 	{	IOLog( "BMacEnet::start: Couldn't allocate KDB buffer\n" );
 		return false;
 	}
-	txDebuggerPkt->m_next = 0;
 
 #if 0
 	// Enable the interrupt event sources. The hardware interrupts
@@ -500,7 +496,7 @@ void BMacEnet::handleInterrupt( IOInterruptEventSource *src )
  *
  *-------------------------------------------------------------------------*/
 
-UInt32 BMacEnet::outputPacket(struct mbuf * pkt, void * param)
+UInt32 BMacEnet::outputPacket( mbuf_t pkt, void *param )
 {
 	u_int32_t	i;
 	UInt32      ret = kIOReturnOutputSuccess;
@@ -986,7 +982,7 @@ void BMacEnet::monitorLinkStatus( bool firstPoll )
                     fullDuplex = false;
                 }
 
-                if ( fullDuplex != isFullDuplex )
+			///	if ( fullDuplex != isFullDuplex )
                 {							
                     _setDuplexMode(fullDuplex);
                 }
